pub struct DirectoryComparer { /* private fields */ }Expand description
A tool for comparing the contents of two directories.
Implementations
Sourceimpl DirectoryComparer
impl DirectoryComparer
Sourcepub fn new(dir1: PathBuf, dir2: PathBuf) -> Self
pub fn new(dir1: PathBuf, dir2: PathBuf) -> Self
Creates a new DirectoryComparer for the two given directories.
Sourcepub fn set_buffer_size(&mut self, size: usize)
pub fn set_buffer_size(&mut self, size: usize)
Sets the buffer size for file comparison in bytes.
Sourcepub fn set_max_threads(parallel: usize) -> Result<()>
pub fn set_max_threads(parallel: usize) -> Result<()>
Sets the maximum number of threads for parallel processing. This initializes the global Rayon thread pool.