pub struct FileHasher {
pub buffer_size: usize,
/* private fields */
}Expand description
A tool for finding duplicated files in a directory.
Fields
buffer_size: usizeImplementations
Sourceimpl FileHasher
impl FileHasher
Sourcepub fn run(&self) -> Result<()>
pub fn run(&self) -> Result<()>
Executes the duplicate file finding process and prints results.
Sourcepub fn find_duplicates(&self) -> Result<Vec<DuplicatedFiles>>
pub fn find_duplicates(&self) -> Result<Vec<DuplicatedFiles>>
Finds duplicated files and returns a list of duplicate groups.